//-*-c++-*-

// This is an empty Behavior template file.
// Replace CLASSNAME and DESCRIPTION as appropriate, and go to town!

#ifndef INCLUDED_CLASSNAME_h_
#define INCLUDED_CLASSNAME_h_

#include "Behaviors/BehaviorBase.h"

//! DESCRIPTION
class CLASSNAME : public BehaviorBase {
public:
	//! constructor
	CLASSNAME() : BehaviorBase("CLASSNAME") {}

	virtual void DoStart() {
		BehaviorBase::DoStart(); // do this first
		// <your startup code here>
	}

	virtual void DoStop() {
		// <your shutdown code here>
		BehaviorBase::DoStop(); // do this last
	}

	virtual void processEvent(const EventBase& e) {
		// <your event processing code here>
		// you can delete this function if you don't use any events...
	}

	static std::string getClassDescription() { return "DESCRIPTION"; }
	virtual std::string getDescription() const { return getClassDescription(); }
	
protected:
	
};

/*! @file
 * @brief Defines CLASSNAME, which DESCRIPTION
 * @author YOURNAMEHERE (Creator)
 *
 * $Author: ejt $
 * $Name: tekkotsu-2_2_1 $
 * $Revision: 1.2 $
 * $State: Exp $
 * $Date: 2004/11/11 20:35:00 $
 */

#endif
